@@ -225,7 +225,7 @@ create table ttrss_tags (id integer primary key auto_increment,
 
 create table ttrss_version (schema_version int not null) TYPE=InnoDB;
 
-insert into ttrss_version values (55);
+insert into ttrss_version values (56);
 
 create table ttrss_enclosures (id serial not null primary key,
 	content_url text not null,
@@ -234,7 +234,7 @@ create table ttrss_enclosures (id serial not null primary key,
 	title text not null,
 	duration text not null,
 	index (post_id),
-	foreign key (post_id) references ttrss_entries(id) ON DELETE cascade);
+	foreign key (post_id) references ttrss_entries(id) ON DELETE cascade) TYPE=InnoDB;
 
 create table ttrss_prefs_types (id integer not null primary key, 
 	type_name varchar(100) not null) TYPE=InnoDB;
